summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/segaic16.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/segaic16.cpp')
-rw-r--r--src/mame/video/segaic16.cpp11
1 files changed, 5 insertions, 6 deletions
diff --git a/src/mame/video/segaic16.cpp b/src/mame/video/segaic16.cpp
index f706c6f2d84..b80c90f981f 100644
--- a/src/mame/video/segaic16.cpp
+++ b/src/mame/video/segaic16.cpp
@@ -389,21 +389,20 @@ segaic16_video_device::segaic16_video_device(const machine_config &mconfig, cons
m_pagelatch_cb = segaic16_video_pagelatch_delegate(FUNC(segaic16_video_device::tilemap_16b_fill_latch), this);
}
-void segaic16_video_device::set_pagelatch_cb(device_t &device,segaic16_video_pagelatch_delegate newtilecb)
+void segaic16_video_device::set_pagelatch_cb(segaic16_video_pagelatch_delegate newtilecb)
{
- segaic16_video_device &dev = downcast<segaic16_video_device &>(device);
- dev.m_pagelatch_cb = newtilecb;
+ m_pagelatch_cb = newtilecb;
}
//-------------------------------------------------
// static_set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------
-void segaic16_video_device::static_set_gfxdecode_tag(device_t &device, const char *tag)
+void segaic16_video_device::set_gfxdecode_tag(const char *tag)
{
- downcast<segaic16_video_device &>(device).m_gfxdecode.set_tag(tag);
+ m_gfxdecode.set_tag(tag);
}
@@ -389,21 +389,20 @@ segaic16_video_device::segaic16_video_device(const machine_config &mconfig, cons
}
//-------------------------------------------------
-// static_set_gfxdecode_tag: Set the tag of the
+// set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------